These files are adapted from the timm library: [https://github.com/rwightman/pytorch-image-models](https://github.com/rwightman/pytorch-image-models).

Most files are stripped down versions of the original ones, but they may also contain small modifications to adapt the modules to our model.

timm is licensed under the Apache 2.0 license: [https://github.com/rwightman/pytorch-image-models/blob/main/LICENSE](https://github.com/rwightman/pytorch-image-models/blob/main/LICENSE).